Particle physics quantities
===========================

Overview
--------

In addition to providing functions for computing gamma-ray and CMB constraints,
the ``Theory`` class has methods for computing a variety of particle physics
quantities, which are documented on this page.

Methods
-------

.. automethod:: hazma.theory.Theory.list_annihilation_final_states

.. automethod:: hazma.theory.Theory.annihilation_cross_sections

.. automethod:: hazma.theory.Theory.annihilation_cross_sections

.. automethod:: hazma.theory.Theory.annihilation_branching_fractions

.. automethod:: hazma.theory.Theory.partial_widths

.. automethod:: hazma.theory.Theory.total_spectrum

.. automethod:: hazma.theory.Theory.gamma_ray_lines

.. automethod:: hazma.theory.Theory.spectra

.. automethod:: hazma.theory.Theory.spectrum_funcs

.. automethod:: hazma.theory.Theory.total_conv_spectrum_fn

.. automethod:: hazma.theory.Theory.total_positron_spectrum

.. automethod:: hazma.theory.Theory.positron_lines

.. automethod:: hazma.theory.Theory.positron_spectra

.. automethod:: hazma.theory.Theory.positron_spectrum_funcs

.. automethod:: hazma.theory.Theory.total_conv_positron_spectrum_fn
